Crate dexterior_core

Crate dexterior_core 

This is the core crate containing most of dexterior’s functionality (specifically, everything except the visuals). See the dexterior crate’s documentation for an in-depth introduction.

Re-exports

pub use nalgebra as na;
pub use nalgebra_sparse as nas;

Modules

cochain
Cochains, i.e. values assigned to elements of a mesh.
gmsh
Utilities for loading meshes generated with gmsh.
interpolate
Utilities for interpolating cochain values on a mesh.
mesh
The core discretization structure of DEC, the (simplicial) mesh.
operator
Composable operators for doing math on Cochains.
quadrature
Operations for integrating functions over simplices.

Structs

DiagonalOperator
A diagonal matrix operator.
Dual
Marker type indicating a Cochain or operator corresponds to a dual mesh.
DualCellIter
Iterator over a set of DIM-dimensional dual cells in a mesh.
DualCellView
A view into a dual cell’s data.
MatrixOperator
A general sparse matrix operator, parameterized with the cochain types it consumes and produces.
Primal
Marker type indicating a Cochain or operator corresponds to a primal mesh.
SimplexIter
Iterator over a set of DIM-simplices in a mesh.
SimplexView
A view into a single simplex’s data.
SimplicialMesh
A DEC mesh where the primal cells are all simplices (points, line segments, triangles, tetrahedra etc).

Traits

Operator
Trait enabling operator composition checked for compatibility at compile time.

Type Aliases

Cochain
A vector of values corresponding to a set of k-dimensional cells on a mesh.
Op
A type alias for MatrixOperator to make common patterns more convenient to type.
Subset
A subset of cells in a mesh.
Unit
Type alias for a general nalgebra unit vector.
UnitVec2
Type alias for a 2D nalgebra unit vector.
UnitVec3
Type alias for a 3D nalgebra unit vector.
Vec2
Type alias for a 2D nalgebra vector.
Vec3
Type alias for a 3D nalgebra vector.