pub struct MatrixOperator<Input, Output> {
pub mat: CsrMatrix<f64>,
/* private fields */
}Expand description
A general sparse matrix operator, parameterized with the cochain types it consumes and produces.
This can be a composition of one or more MatrixOperators and DiagonalOperators.
Composition can be done using multiplication syntax:
let op: MatrixOperator<_, _> = mesh.star() * mesh.d::<1, Primal>();A free function compose is also provided for the same purpose.
There is also a DiagonalOperator type for operators
which are specifically diagonal matrices,
which stores them in a somewhat more efficient format.
When you don’t need the efficiency and prefer notational convenience,
these can also be converted into a MatrixOperator using the std From trait.
This enables writing all your operator types as MatrixOperator<Input, Output>,
a convenient pattern which can be written more concisely with the type alias Op.
See the crate-level docs and examples for details.
Fields
mat: CsrMatrix<f64>The underlying matrix, exposed for potential use cases that need to modify or read matrix values directly.
Modifying the dimensions of this matrix will result in runtime errors.
Implementations
Sourceimpl<Input, Output> MatrixOperator<Input, Output>
impl<Input, Output> MatrixOperator<Input, Output>
Sourcepub fn exclude_subset(
self,
set: &SubsetImpl<<Output as Operand>::Dimension, <Output as Operand>::Primality>,
) -> Self
pub fn exclude_subset( self, set: &SubsetImpl<<Output as Operand>::Dimension, <Output as Operand>::Primality>, ) -> Self
Set a subset of elements in the output cochain to zero when this operator is applied (i.e. set a subset of rows in the operator matrix to zero).