This is the core crate containing most of dexterior’s functionality
(specifically, everything except the visuals).
See the dexterior crate’s documentation for an in-depth introduction.
Re-exports
pub use nalgebra as na;pub use nalgebra_sparse as nas;
Modules
- cochain
- Cochains, i.e. values assigned to elements of a mesh.
- gmsh
- Utilities for loading meshes generated with
gmsh. - interpolate
- Utilities for interpolating cochain values on a mesh.
- mesh
- The core discretization structure of DEC, the (simplicial) mesh.
- operator
- Composable operators for doing math on
Cochains. - quadrature
- Operations for integrating functions over simplices.
Structs
- Diagonal
Operator - A diagonal matrix operator.
- Dual
- Marker type indicating a
Cochainoroperatorcorresponds to a dual mesh. - Dual
Cell Iter - Iterator over a set of
DIM-dimensional dual cells in a mesh. - Dual
Cell View - A view into a dual cell’s data.
- Matrix
Operator - A general sparse matrix operator, parameterized with the cochain types it consumes and produces.
- Primal
- Marker type indicating a
Cochainoroperatorcorresponds to a primal mesh. - Simplex
Iter - Iterator over a set of
DIM-simplices in a mesh. - Simplex
View - A view into a single simplex’s data.
- Simplicial
Mesh - A DEC mesh where the primal cells are all simplices (points, line segments, triangles, tetrahedra etc).
Traits
- Operator
- Trait enabling operator composition checked for compatibility at compile time.
Type Aliases
- Cochain
- A vector of values corresponding to
a set of
k-dimensional cells on a mesh. - Op
- A type alias for
MatrixOperatorto make common patterns more convenient to type. - Subset
- A subset of cells in a mesh.
- Unit
- Type alias for a general
nalgebraunit vector. - Unit
Vec2 - Type alias for a 2D
nalgebraunit vector. - Unit
Vec3 - Type alias for a 3D
nalgebraunit vector. - Vec2
- Type alias for a 2D
nalgebravector. - Vec3
- Type alias for a 3D
nalgebravector.